@@ -5,6 +5,9 @@ from packaging import version
 from kabaret import flow
 from kabaret.subprocess_manager.runners import Explorer
 
+from libreflow import _version as libreflow_version
+from libreflow.flows import _version as libreflowthesiren_version
+
 from ..resources import file_templates
 from ..resources.icons import flow as icons_flow
 
@@ -42,7 +45,7 @@ class ProjectSettings(BaseProjectSettings):
 
     publish_ok_files = flow.Param('').ui(editable=False)
     libreflow_version = flow.Param('0.0.0').ui(editable=False)
-    libreflow_siren_version = flow.Param('0.0.0').ui(editable=False)
+    project_version = flow.Param('0.0.0').ui(editable=False)
 
 
 class Project(BaseProject, flow.InjectionProvider):
@@ -78,9 +81,9 @@ class Project(BaseProject, flow.InjectionProvider):
 
     def update_user_last_visit(self):
         user_login = self.get_user()
-        requieredVersion = self.get_requiered_versions()
+        requiredVersion = self.get_required_versions()
 
-        if not user_login or not requieredVersion:
+        if not user_login or not requiredVersion:
             return
 
         users = self.admin.users
@@ -90,16 +93,16 @@ class Project(BaseProject, flow.InjectionProvider):
         user = users[user_login]
 
         user._last_visit.set(time.time())
-        for v in requieredVersion:
-            if v[0] == 'libreflow.thesiren':
-                user._last_libreflow_thesiren_used_version.set(v[1])
+        for v in requiredVersion:
+            if v[0] == 'libreflow.flows':
+                user._last_project_used_version.set(v[1])
             elif v[0] == 'libreflow':
                 user._last_libreflow_used_version.set(v[1])
 
-    def get_requiered_versions(self):
+    def get_required_versions(self):
         '''
         return a list of dependencies
-        [dependecyName, currentVersion, requieredVersion, updateNeeded(0:no|1:yes minor|2: yes major)],[]
+        [dependecyName, currentVersion, requiredVersion, updateNeeded(0:no|1:yes minor|2: yes major)],[]
         '''
         versions = []
 
@@ -120,23 +123,23 @@ class Project(BaseProject, flow.InjectionProvider):
 
         versions.append(['libreflow', str(libreflow_cur_version), str(libreflow_req_version), libreflow_needs_update])
         
-        libreflow_sir_cur_version = version.parse(libreflowthesiren_version.get_versions()['version'])
-        libreflow_sir_req_version = version.parse(self.admin.project_settings.libreflow_siren_version.get())
+        project_cur_version = version.parse(libreflowthesiren_version.get_versions()['version'])
+        project_req_version = version.parse(self.admin.project_settings.project_version.get())
 
-        if libreflow_sir_cur_version < libreflow_sir_req_version \
-                and ((libreflow_sir_cur_version.major < libreflow_sir_req_version.major) or \
-                    (libreflow_sir_cur_version.minor < libreflow_sir_req_version.minor)):
+        if project_cur_version < project_req_version \
+                and ((project_cur_version.major < project_req_version.major) or \
+                    (project_cur_version.minor < project_req_version.minor)):
             # VERY IMPORTANT UPDATE
-            libreflow_sir_needs_update = 2
-        elif libreflow_sir_cur_version < libreflow_sir_req_version:
+            project_needs_update = 2
+        elif project_cur_version < project_req_version:
             # MINOR UPDATE
-            libreflow_sir_needs_update = 1
+            project_needs_update = 1
         else:
             # NO UDPATE
-            libreflow_sir_needs_update = 0
+            project_needs_update = 0
 
        
-        versions.append(['libreflow.thesiren', str(libreflow_sir_cur_version), str(libreflow_sir_req_version), libreflow_sir_needs_update])
+        versions.append(['libreflow.flows', str(project_cur_version), str(project_req_version), project_needs_update])
     
         for v in versions:
             print(v)
